Learn R Programming

corazon (version 0.1.0)

available_gradients: Display available gradient colors

Description

the function displays the available gradient colors contained within the package along with their corresponding hex colors

Usage

available_gradients()

Arguments

Value

a character vector

Examples

Run this code
# NOT RUN {
available_gradients()


# }
# NOT RUN {


# }

Run the code above in your browser using DataLab