powered by
the function displays the available gradient colors contained within the package along with their corresponding hex colors
available_gradients()
a character vector
# NOT RUN { available_gradients() # } # NOT RUN { # }
Run the code above in your browser using DataLab